
<!doctype html>
<html lang="us">
<head>
	<meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="description" content="">
    <meta name="author" content="">
	<title>ScapInspector Example</title>
    <link rel="stylesheet" href="/node_modules/bootstrap/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="/node_modules/tablesorter/dist/css/theme.bootstrap_4.min.css">
    <script src="/node_modules/@fortawesome/fontawesome-free/css/all.min.css"></script>
    <link rel="stylesheet" href="/node_modules/scapinspector/dist/css/scapinspector.css" />
	<style>
	</style>
</head>
<body>


    <div class="container-fluid">
      <div class="row">
        <main role="main" class="col-md-10 col-lg-10 mx-auto pt-5 px-4">
          <div class="scapinspector-message"></div>
          <h2 class="scapinspector-heading"></h2>
          <!-- all the magic happens here -->
          <div class="scapinspector table-responsive"></div>
        </main>
      </div>
    </div>
	
	
  <script src="/node_modules/@fortawesome/fontawesome-free/js/all.js"></script>
  <script src="/node_modules/jquery/dist/jquery.min.js"></script>
  <script src="/node_modules/bootstrap/dist/js/bootstrap.min.js"></script>
  <script src="/node_modules/popper.js-lite/dist/popper.min.js"></script>
  <script src="/node_modules/tablesorter/dist/js/jquery.tablesorter.min.js"></script>
  <script src="/node_modules/tablesorter/dist/js/extras/jquery.tablesorter.pager.min.js"></script>
  <script src="/node_modules/tablesorter/dist/js/jquery.tablesorter.widgets.min.js"></script>
  
  <script src="/node_modules/scapinspector/dist/js/scapinspector.js"></script>
  		
	<script>
	   $(".scapinspector").scapinspector();
	</script>
</body>
</html>
